BuildError

Enum BuildError 

pub enum BuildError {
    UnknownInstruction,
    ArgCountMismatch {
        expected: usize,
        got: usize,
    },
    ArgSizeMismatch {
        index: usize,
        expected: u16,
        got: usize,
    },
    AccountCountMismatch {
        expected: usize,
        got: usize,
    },
}
Builder error surface.

Variants



UnknownInstruction

No instruction by that name in the manifest.



ArgCountMismatch

Caller supplied a different number of args than the manifest declares.

Fields

expected: usize

Expected count.

got: usize

Actual count.



ArgSizeMismatch

One of the caller’s arg byte slices was the wrong size.

Fields

index: usize

Which arg index.

expected: u16

Expected size from manifest.

got: usize

Actual size from caller.



AccountCountMismatch

Caller supplied a different number of accounts than the manifest declares for this instruction.

Fields

expected: usize

Expected count.

got: usize

Actual count.