pub enum BuildError {
UnknownInstruction,
ArgCountMismatch {
expected: usize,
got: usize,
},
ArgSizeMismatch {
index: usize,
expected: u16,
got: usize,
},
AccountCountMismatch {
expected: usize,
got: usize,
},
}Expand description
Builder error surface.
Variants
UnknownInstruction
No instruction by that name in the manifest.
ArgCountMismatch
Caller supplied a different number of args than the manifest declares.
ArgSizeMismatch
One of the caller’s arg byte slices was the wrong size.
Fields
AccountCountMismatch
Caller supplied a different number of accounts than the manifest declares for this instruction.