pub enum ReceiptError {
TooShort {
got: usize,
},
ReservedNonZero,
InvalidPhase(u8),
InvalidCompatImpact(u8),
InvalidFailureStage(u8),
}Expand description
Receipt parse error.
Variants
TooShort
Input was shorter than RECEIPT_SIZE_LEGACY bytes.
ReservedNonZero
Reserved trailing region was non-zero. likely corrupt or stale.
InvalidPhase(u8)
phase byte is outside the documented enum range (0..=4).
InvalidCompatImpact(u8)
compat_impact byte is outside the documented enum range (0..=3).
InvalidFailureStage(u8)
failure_stage byte is outside the documented enum range (0..=5).